/// <reference types="node" />
import http = require('http');
import { Dashboard } from '../model/dashboard';
import { DashboardList } from '../model/dashboardList';
import { EntityShortRepresentation } from '../model/entityShortRepresentation';
import { Authentication, Interceptor } from '../model/models';
import { ApiKeyAuth } from '../model/models';
export declare enum DashboardsApiApiKeys {
    Api = 0
}
export declare class DashboardsApi {
    protected _basePath: string;
    protected _defaultHeaders: any;
    protected _useQuerystring: boolean;
    protected authentications: {
        'default': Authentication;
        'Api-Token': ApiKeyAuth;
    };
    protected interceptors: Interceptor[];
    constructor(basePath?: string);
    useQuerystring: boolean;
    basePath: string;
    defaultHeaders: any;
    setDefaultAuthentication(auth: Authentication): void;
    setApiKey(key: DashboardsApiApiKeys, value: string): void;
    addInterceptor(interceptor: Interceptor): void;
    createDashboard(dashboard?: Dashboard, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: EntityShortRepresentation;
    }>;
    deleteDashboard(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    getDashboard(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: Dashboard;
    }>;
    getDashboardMetadata(options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: DashboardList;
    }>;
    updateDashboard(id: string, dashboard?: Dashboard, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: EntityShortRepresentation;
    }>;
    validateDashboardCreation(dashboard?: Dashboard, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    validateDashboardUpdate(id: string, dashboard?: Dashboard, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
}
