/// <reference types="node" />
import http = require('http');
import { EntityShortRepresentation } from '../model/entityShortRepresentation';
import { Extension } from '../model/extension';
import { ExtensionConfigurationDto } from '../model/extensionConfigurationDto';
import { ExtensionConfigurationList } from '../model/extensionConfigurationList';
import { ExtensionListDto } from '../model/extensionListDto';
import { ExtensionStateList } from '../model/extensionStateList';
import { GlobalExtensionConfiguration } from '../model/globalExtensionConfiguration';
import { HostList } from '../model/hostList';
import { StubList } from '../model/stubList';
import { Authentication, Interceptor } from '../model/models';
import { ApiKeyAuth } from '../model/models';
import { RequestFile } from './apis';
export declare enum ExtensionsApiApiKeys {
    Api = 0
}
export declare class ExtensionsApi {
    protected _basePath: string;
    protected _defaultHeaders: any;
    protected _useQuerystring: boolean;
    protected authentications: {
        'default': Authentication;
        'Api-Token': ApiKeyAuth;
    };
    protected interceptors: Interceptor[];
    constructor(basePath?: string);
    useQuerystring: boolean;
    basePath: string;
    defaultHeaders: any;
    setDefaultAuthentication(auth: Authentication): void;
    setApiKey(key: ExtensionsApiApiKeys, value: string): void;
    addInterceptor(interceptor: Interceptor): void;
    createLocalExtensionConfiguration(id: string, extensionConfigurationDto?: ExtensionConfigurationDto, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: EntityShortRepresentation;
    }>;
    deleteExtension(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    deleteLocalExtensionConfiguration(id: string, configurationId: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    getExtension(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: Extension;
    }>;
    getExtensionBinary(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    getExtensionConfigurations(id: string, pageSize?: number, nextPageKey?: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: ExtensionConfigurationList;
    }>;
    getExtensionGlobalConfiguration(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: GlobalExtensionConfiguration;
    }>;
    getExtensionStates(id: string, pageSize?: number, nextPageKey?: string, state?: 'DISABLED' | 'ERROR_AUTH' | 'ERROR_COMMUNICATION_FAILURE' | 'ERROR_CONFIG' | 'ERROR_TIMEOUT' | 'ERROR_UNKNOWN' | 'INCOMPATIBLE' | 'LIMIT_REACHED' | 'NOTHING_TO_REPORT' | 'OK' | 'STATE_TYPE_UNKNOWN' | 'UNINITIALIZED' | 'UNSUPPORTED' | 'WAITING_FOR_STATE', options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: ExtensionStateList;
    }>;
    getExtensions(pageSize?: number, nextPageKey?: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: ExtensionListDto;
    }>;
    getHostsForTechnology(technology: 'ACTIVE_MQ' | 'ACTIVE_MQ_ARTEMIS' | 'ADO_NET' | 'AIX' | 'AKKA' | 'AMAZON_REDSHIFT' | 'AMQP' | 'APACHE_CAMEL' | 'APACHE_CASSANDRA' | 'APACHE_COUCH_DB' | 'APACHE_DERBY' | 'APACHE_HTTP_CLIENT_ASYNC' | 'APACHE_HTTP_CLIENT_SYNC' | 'APACHE_HTTP_SERVER' | 'APACHE_KAFKA' | 'APACHE_SOLR' | 'APACHE_STORM' | 'APACHE_SYNAPSE' | 'APACHE_TOMCAT' | 'APPARMOR' | 'APPLICATION_INSIGHTS_SDK' | 'ASP_DOTNET' | 'ASP_DOTNET_CORE' | 'ASP_DOTNET_CORE_SIGNALR' | 'ASP_DOTNET_SIGNALR' | 'AWS_LAMBDA' | 'AWS_RDS' | 'AWS_SERVICE' | 'AXIS' | 'AZURE_FUNCTIONS' | 'AZURE_SERVICE_BUS' | 'AZURE_SERVICE_FABRIC' | 'AZURE_STORAGE' | 'BOSHBPM' | 'CITRIX' | 'CITRIX_COMMON' | 'CITRIX_DESKTOP_DELIVERY_CONTROLLERS' | 'CITRIX_DIRECTOR' | 'CITRIX_LICENSE_SERVER' | 'CITRIX_PROVISIONING_SERVICES' | 'CITRIX_STOREFRONT' | 'CITRIX_VIRTUAL_DELIVERY_AGENT' | 'CITRIX_WORKSPACE_ENVIRONMENT_MANAGEMENT' | 'CLOUDFOUNDRY' | 'CLOUDFOUNDRY_AUCTIONEER' | 'CLOUDFOUNDRY_BOSH' | 'CLOUDFOUNDRY_GOROUTER' | 'COLDFUSION' | 'CONTAINERD' | 'CORE_DNS' | 'COUCHBASE' | 'CRIO' | 'CXF' | 'DATASTAX' | 'DB2' | 'DIEGO_CELL' | 'DOCKER' | 'DOTNET' | 'DOTNET_REMOTING' | 'ELASTIC_SEARCH' | 'ENVOY' | 'ERLANG' | 'ETCD' | 'F5_LTM' | 'FSHARP' | 'GARDEN' | 'GLASSFISH' | 'GO' | 'GRPC' | 'GRSECURITY' | 'HADOOP' | 'HADOOP_HDFS' | 'HADOOP_YARN' | 'HAPROXY' | 'HEAT' | 'HESSIAN' | 'HORNET_Q' | 'IBM_CICS_REGION' | 'IBM_CICS_TRANSACTION_GATEWAY' | 'IBM_IMS_CONNECT_REGION' | 'IBM_IMS_CONTROL_REGION' | 'IBM_IMS_MESSAGE_PROCESSING_REGION' | 'IBM_IMS_SOAP_GATEWAY' | 'IBM_INTEGRATION_BUS' | 'IBM_MQ' | 'IBM_MQ_CLIENT' | 'IBM_WEBSHPRERE_APPLICATION_SERVER' | 'IBM_WEBSHPRERE_LIBERTY' | 'IIS' | 'IIS_APP_POOL' | 'ISTIO' | 'JAVA' | 'JAX_WS' | 'JBOSS' | 'JBOSS_EAP' | 'JDK_HTTP_SERVER' | 'JERSEY' | 'JETTY' | 'JRUBY' | 'JYTHON' | 'KUBERNETES' | 'LIBVIRT' | 'LINKERD' | 'MARIADB' | 'MEMCACHED' | 'MICROSOFT_SQL_SERVER' | 'MONGODB' | 'MSSQL_CLIENT' | 'MULE_ESB' | 'MYSQL' | 'MYSQL_CONNECTOR' | 'NETFLIX_SERVO' | 'NETTY' | 'NGINX' | 'NODE_JS' | 'ONEAGENT_SDK' | 'OPENCENSUS' | 'OPENSHIFT' | 'OPENSTACK_COMPUTE' | 'OPENSTACK_CONTROLLER' | 'OPENTELEMETRY' | 'OPENTRACING' | 'OPEN_LIBERTY' | 'ORACLE_DATABASE' | 'ORACLE_WEBLOGIC' | 'OWIN' | 'PERL' | 'PHP' | 'PHP_FPM' | 'PLAY' | 'POSTGRE_SQL' | 'POSTGRE_SQL_DOTNET_DATA_PROVIDER' | 'POWER_DNS' | 'PROGRESS' | 'PYTHON' | 'RABBIT_MQ' | 'REDIS' | 'RESTEASY' | 'RESTLET' | 'RIAK' | 'RUBY' | 'SAG_WEBMETHODS_IS' | 'SAP' | 'SAP_HANADB' | 'SAP_HYBRIS' | 'SAP_MAXDB' | 'SAP_SYBASE' | 'SCALA' | 'SELINUX' | 'SHAREPOINT' | 'SPARK' | 'SPRING' | 'SQLITE' | 'THRIFT' | 'TIBCO' | 'TIBCO_BUSINESS_WORKS' | 'TIBCO_EMS' | 'VARNISH_CACHE' | 'VIM2' | 'VIRTUAL_MACHINE_KVM' | 'VIRTUAL_MACHINE_QEMU' | 'WILDFLY' | 'WINDOWS_CONTAINERS' | 'WINK' | 'ZERO_MQ', tag?: Array<string>, managementZone?: number, hostGroupId?: string, hostGroupName?: string, pageSize?: number, nextPageKey?: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: HostList;
    }>;
    getLocalExtensionConfiguration(id: string, configurationId: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: ExtensionConfigurationDto;
    }>;
    getRemoteExtensionModules(options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: StubList;
    }>;
    updateGlobalExtensionConfiguration(id: string, globalExtensionConfiguration?: GlobalExtensionConfiguration, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    updateLocalExtensionConfiguration(id: string, configurationId: string, extensionConfigurationDto?: ExtensionConfigurationDto, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    uploadExtension(file: RequestFile, overrideAlerts?: boolean, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: EntityShortRepresentation;
    }>;
    validateExtension(file: RequestFile, jsonOnly?: boolean, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    validateLocalExtensionConfiguration(id: string, extensionConfigurationDto?: ExtensionConfigurationDto, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
}
