/// <reference types="node" />
import http = require('http');
import { SupportedVersion } from '../model/supportedVersion';
import { SymbolFile } from '../model/symbolFile';
import { SymbolFileClientLinkDto } from '../model/symbolFileClientLinkDto';
import { SymbolFileList } from '../model/symbolFileList';
import { SymbolFilePinning } from '../model/symbolFilePinning';
import { SymbolFileStorageInfo } from '../model/symbolFileStorageInfo';
import { Authentication, Interceptor } from '../model/models';
import { ApiKeyAuth } from '../model/models';
import { RequestFile } from './apis';
export declare enum MobileDeobfuscationAndSymbolicationApiApiKeys {
    Api = 0
}
export declare class MobileDeobfuscationAndSymbolicationApi {
    protected _basePath: string;
    protected _defaultHeaders: any;
    protected _useQuerystring: boolean;
    protected authentications: {
        'default': Authentication;
        'Api-Token': ApiKeyAuth;
    };
    protected interceptors: Interceptor[];
    constructor(basePath?: string);
    useQuerystring: boolean;
    basePath: string;
    defaultHeaders: any;
    setDefaultAuthentication(auth: Authentication): void;
    setApiKey(key: MobileDeobfuscationAndSymbolicationApiApiKeys, value: string): void;
    addInterceptor(interceptor: Interceptor): void;
    createOrUpdate(applicationId: string, packageName: string, os: 'ANDROID' | 'IOS' | 'TVOS', versionCode: string, versionName: string, body: RequestFile, contentType?: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    createOrUpdatePinning(applicationId: string, packageName: string, os: 'ANDROID' | 'IOS' | 'TVOS', versionCode: string, versionName: string, symbolFilePinning?: SymbolFilePinning, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    deleteApp(applicationId: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    deleteSingleFile(applicationId: string, packageName: string, os: 'ANDROID' | 'IOS' | 'TVOS', versionCode: string, versionName: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    getAll(options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: SymbolFileList;
    }>;
    getAllPerApplication(applicationId: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: SymbolFileList;
    }>;
    getDssClientUrl(options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: SymbolFileClientLinkDto;
    }>;
    getInfo(options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: SymbolFileStorageInfo;
    }>;
    getSingle(applicationId: string, packageName: string, os: 'ANDROID' | 'IOS' | 'TVOS', versionCode: string, versionName: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: SymbolFile;
    }>;
    getSupportedVersion(options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: SupportedVersion;
    }>;
    validatePinning(applicationId: string, packageName: string, os: 'ANDROID' | 'IOS' | 'TVOS', versionCode: string, versionName: string, symbolFilePinning?: SymbolFilePinning, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
}
