/// <reference types="node" />
import http = require('http');
import { EntityShortRepresentation } from '../model/entityShortRepresentation';
import { Plugin } from '../model/plugin';
import { PluginStateList } from '../model/pluginStateList';
import { RemotePluginEndpoint } from '../model/remotePluginEndpoint';
import { StubList } from '../model/stubList';
import { Authentication, Interceptor } from '../model/models';
import { ApiKeyAuth } from '../model/models';
import { RequestFile } from './apis';
export declare enum PluginsApiApiKeys {
    Api = 0
}
export declare class PluginsApi {
    protected _basePath: string;
    protected _defaultHeaders: any;
    protected _useQuerystring: boolean;
    protected authentications: {
        'default': Authentication;
        'Api-Token': ApiKeyAuth;
    };
    protected interceptors: Interceptor[];
    constructor(basePath?: string);
    useQuerystring: boolean;
    basePath: string;
    defaultHeaders: any;
    setDefaultAuthentication(auth: Authentication): void;
    setApiKey(key: PluginsApiApiKeys, value: string): void;
    addInterceptor(interceptor: Interceptor): void;
    createRemotePluginEndpoint(id: string, remotePluginEndpoint?: RemotePluginEndpoint, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: EntityShortRepresentation;
    }>;
    deletePlugin(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    deleteRemotePluginEndpoint(id: string, endpointId: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    getPlugin(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: Plugin;
    }>;
    getPluginBinary(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: object;
    }>;
    getPluginStates(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: PluginStateList;
    }>;
    getPlugins(options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: StubList;
    }>;
    getRemotePluginEndpoint(id: string, endpointId: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: RemotePluginEndpoint;
    }>;
    getRemotePluginEndpoints(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: StubList;
    }>;
    getRemotePluginModules(options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: StubList;
    }>;
    updateRemotePluginEndpoint(id: string, endpointId: string, remotePluginEndpoint?: RemotePluginEndpoint, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    uploadPlugin(file: RequestFile, overrideAlerts?: boolean, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: EntityShortRepresentation;
    }>;
    validatePlugin(file: RequestFile, jsonOnly?: boolean, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    validateRemotePluginEndpoint(id: string, remotePluginEndpoint?: RemotePluginEndpoint, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
}
