/// <reference types="node" />
import http = require('http');
import { DashboardReport } from '../model/dashboardReport';
import { EntityShortRepresentation } from '../model/entityShortRepresentation';
import { ReportStubList } from '../model/reportStubList';
import { ReportSubscriptions } from '../model/reportSubscriptions';
import { Authentication, Interceptor } from '../model/models';
import { ApiKeyAuth } from '../model/models';
export declare enum ReportsApiApiKeys {
    Api = 0
}
export declare class ReportsApi {
    protected _basePath: string;
    protected _defaultHeaders: any;
    protected _useQuerystring: boolean;
    protected authentications: {
        'default': Authentication;
        'Api-Token': ApiKeyAuth;
    };
    protected interceptors: Interceptor[];
    constructor(basePath?: string);
    useQuerystring: boolean;
    basePath: string;
    defaultHeaders: any;
    setDefaultAuthentication(auth: Authentication): void;
    setApiKey(key: ReportsApiApiKeys, value: string): void;
    addInterceptor(interceptor: Interceptor): void;
    createOrUpdateReport(id: string, dashboardReport?: DashboardReport, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: EntityShortRepresentation;
    }>;
    createReport(dashboardReport?: DashboardReport, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: EntityShortRepresentation;
    }>;
    deleteReport(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    getReport(id: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: DashboardReport;
    }>;
    listReports(type?: 'DASHBOARD', sourceId?: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: ReportStubList;
    }>;
    subscribeReport(id: string, reportSubscriptions?: ReportSubscriptions, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: EntityShortRepresentation;
    }>;
    unsubscribeReport(id: string, reportSubscriptions?: ReportSubscriptions, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body: EntityShortRepresentation;
    }>;
    validateCreateOrUpdateReport(id: string, dashboardReport?: DashboardReport, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
    validateCreateReport(dashboardReport?: DashboardReport, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.ClientResponse;
        body?: any;
    }>;
}
