/**
 * Dynatrace Configuration API
 * Documentation of the Dynatrace Configuration API. Refer to the [help page](https://www.dynatrace.com/support/help/shortlink/config-api) to read about use-cases and examples.  Notes about compatibility: * Operations marked as early adopter or preview may be changed in non-compatible ways, although we try to avoid this. * We may add new enum constants without incrementing the API version; thus, clients need to handle unknown enum constants gracefully.
 *
 * The version of the OpenAPI document: 1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { RequestFile } from '../api';
import { AzureSupportingService } from './azureSupportingService';
import { CloudTag } from './cloudTag';
import { ConfigurationMetadata } from './configurationMetadata';

/**
* Configuration of Azure app-level credentials.
*/
export class AzureCredentials {
    'metadata'?: ConfigurationMetadata;
    /**
    * The Dynatrace entity ID of the Azure credentials configuration.
    */
    'id'?: string;
    /**
    * The unique name of the Azure credentials configuration.   Allowed characters are letters, numbers, and spaces. Also the special characters `.+-_` are allowed.
    */
    'label': string;
    /**
    * The Application ID (also referred to as Client ID)   The combination of Application ID and Directory ID must be unique.
    */
    'appId': string;
    /**
    * The Directory ID (also referred to as Tenant ID)   The combination of Application ID and Directory ID must be unique.
    */
    'directoryId': string;
    /**
    * The secret key associated with the Application ID.   For security reasons, GET requests return this field as `null`.    Submit your key on creation or update of the configuration. If the field is omitted during an update, the old value remains unaffected.
    */
    'key'?: string;
    /**
    * The monitoring is enabled (`true`) or disabled (`false`).   If not set on creation, the `true` value is used.   If the field is omitted during an update, the old value remains unaffected.
    */
    'active'?: boolean;
    /**
    * The automatic capture of Azure tags is on (`true`) or off (`false`).
    */
    'autoTagging': boolean;
    /**
    * Monitor only resources that have specified Azure tags (`true`) or all resources (`false`).
    */
    'monitorOnlyTaggedEntities': boolean;
    /**
    * A list of Azure tags to be monitored.   You can specify up to 10 tags. A resource tagged with *any* of the specified tags is monitored.   Only applicable when the **monitorOnlyTaggedEntities** parameter is set to `true`.
    */
    'monitorOnlyTagPairs': Array<CloudTag>;
    /**
    * A list of Azure supporting services to be monitored. For each service there\'s a sublist of its metrics and the metrics\' dimensions that should be monitored. All of these elements (services, metrics, dimensions) must have corresponding static definitions on the server.
    */
    'supportingServices'?: Array<AzureSupportingService>;

    static discriminator: string | undefined = undefined;

    static attributeTypeMap: Array<{name: string, baseName: string, type: string}> = [
        {
            "name": "metadata",
            "baseName": "metadata",
            "type": "ConfigurationMetadata"
        },
        {
            "name": "id",
            "baseName": "id",
            "type": "string"
        },
        {
            "name": "label",
            "baseName": "label",
            "type": "string"
        },
        {
            "name": "appId",
            "baseName": "appId",
            "type": "string"
        },
        {
            "name": "directoryId",
            "baseName": "directoryId",
            "type": "string"
        },
        {
            "name": "key",
            "baseName": "key",
            "type": "string"
        },
        {
            "name": "active",
            "baseName": "active",
            "type": "boolean"
        },
        {
            "name": "autoTagging",
            "baseName": "autoTagging",
            "type": "boolean"
        },
        {
            "name": "monitorOnlyTaggedEntities",
            "baseName": "monitorOnlyTaggedEntities",
            "type": "boolean"
        },
        {
            "name": "monitorOnlyTagPairs",
            "baseName": "monitorOnlyTagPairs",
            "type": "Array<CloudTag>"
        },
        {
            "name": "supportingServices",
            "baseName": "supportingServices",
            "type": "Array<AzureSupportingService>"
        }    ];

    static getAttributeTypeMap() {
        return AzureCredentials.attributeTypeMap;
    }
}

