/**
 * Dynatrace Configuration API
 * Documentation of the Dynatrace Configuration API. Refer to the [help page](https://www.dynatrace.com/support/help/shortlink/config-api) to read about use-cases and examples.  Notes about compatibility: * Operations marked as early adopter or preview may be changed in non-compatible ways, although we try to avoid this. * We may add new enum constants without incrementing the API version; thus, clients need to handle unknown enum constants gracefully.
 *
 * The version of the OpenAPI document: 1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { RequestFile } from '../api';

/**
* User actions filter of the calculated metric for mobile or custom app.
*/
export class CalculatedMobileMetricUserActionFilter {
    /**
    * The error status of the actions to be included in the metric calculation:   * `true`: Only actions with reported errors are included.    * `false`: All actions are included.
    */
    'hasReportedError'?: boolean;
    /**
    * The HTTP error status of the actions to be included in the metric calculation:   * `true`: Only actions with HTTP errors are included.    * `false`: All actions are included.
    */
    'hasHttpError'?: boolean;
    /**
    * Only actions with this name are included in the metric calculation.    The EQUALS operator applies.
    */
    'userActionName'?: string;
    /**
    * Only actions coming from this app version are included in the metric calculation.    The EQUALS operator applies.
    */
    'appVersion'?: string;
    /**
    * Only actions coming from this app version are included in the metric calculation.    The EQUALS operator applies.
    */
    'device'?: string;
    /**
    * Only actions coming from devices of this manufacturer are included in the metric calculation.    The EQUALS operator applies.
    */
    'manufacturer'?: string;
    /**
    * Only actions with the specified Apdex score are included in the metric calculation.
    */
    'apdex'?: CalculatedMobileMetricUserActionFilter.ApdexEnum;
    /**
    * Only actions coming from this OS family are included in the metric calculation.    Specify the OS ID here.
    */
    'osFamily'?: string;
    /**
    * Only actions coming from this OS version are included in the metric calculation.    Specify the OS ID here.
    */
    'osVersion'?: string;
    /**
    * Only actions of users from this city are included in the metric calculation.    Specify geolocation ID here.
    */
    'city'?: string;
    /**
    * Only actions of users from this continent are included in the metric calculation.    Specify geolocation ID here.
    */
    'continent'?: string;
    /**
    * Only actions of users from this country are included in the metric calculation.    Specify geolocation ID here.
    */
    'country'?: string;
    /**
    * Only actions of users from this region are included in the metric calculation.    Specify geolocation ID here.
    */
    'region'?: string;
    /**
    * Only actions with a duration more than or equal to this value (in milliseconds) are included in the metric calculation.
    */
    'actionDurationFromMilliseconds'?: number;
    /**
    * Only actions with a duration less than or equal to this value (in milliseconds) are included in the metric calculation.
    */
    'actionDurationToMilliseconds'?: number;
    /**
    * Only actions coming from this carrier type are included in the metric calculation.
    */
    'carrier'?: string;
    /**
    * Only actions coming from this connection type are included in the metric calculation.
    */
    'connectionType'?: CalculatedMobileMetricUserActionFilter.ConnectionTypeEnum;
    /**
    * Filter by network technology
    */
    'networkTechnology'?: string;
    /**
    * Only actions coming from this internet service provider are included in the metric calculation.     The EQUALS operator applies.
    */
    'isp'?: string;
    /**
    * Only actions coming from devices with this display orientation are included in the metric calculation.
    */
    'orientation'?: CalculatedMobileMetricUserActionFilter.OrientationEnum;
    /**
    * Only actions coming from devices with this display resolution are included in the metric calculation.
    */
    'resolution'?: CalculatedMobileMetricUserActionFilter.ResolutionEnum;

    static discriminator: string | undefined = undefined;

    static attributeTypeMap: Array<{name: string, baseName: string, type: string}> = [
        {
            "name": "hasReportedError",
            "baseName": "hasReportedError",
            "type": "boolean"
        },
        {
            "name": "hasHttpError",
            "baseName": "hasHttpError",
            "type": "boolean"
        },
        {
            "name": "userActionName",
            "baseName": "userActionName",
            "type": "string"
        },
        {
            "name": "appVersion",
            "baseName": "appVersion",
            "type": "string"
        },
        {
            "name": "device",
            "baseName": "device",
            "type": "string"
        },
        {
            "name": "manufacturer",
            "baseName": "manufacturer",
            "type": "string"
        },
        {
            "name": "apdex",
            "baseName": "apdex",
            "type": "CalculatedMobileMetricUserActionFilter.ApdexEnum"
        },
        {
            "name": "osFamily",
            "baseName": "osFamily",
            "type": "string"
        },
        {
            "name": "osVersion",
            "baseName": "osVersion",
            "type": "string"
        },
        {
            "name": "city",
            "baseName": "city",
            "type": "string"
        },
        {
            "name": "continent",
            "baseName": "continent",
            "type": "string"
        },
        {
            "name": "country",
            "baseName": "country",
            "type": "string"
        },
        {
            "name": "region",
            "baseName": "region",
            "type": "string"
        },
        {
            "name": "actionDurationFromMilliseconds",
            "baseName": "actionDurationFromMilliseconds",
            "type": "number"
        },
        {
            "name": "actionDurationToMilliseconds",
            "baseName": "actionDurationToMilliseconds",
            "type": "number"
        },
        {
            "name": "carrier",
            "baseName": "carrier",
            "type": "string"
        },
        {
            "name": "connectionType",
            "baseName": "connectionType",
            "type": "CalculatedMobileMetricUserActionFilter.ConnectionTypeEnum"
        },
        {
            "name": "networkTechnology",
            "baseName": "networkTechnology",
            "type": "string"
        },
        {
            "name": "isp",
            "baseName": "isp",
            "type": "string"
        },
        {
            "name": "orientation",
            "baseName": "orientation",
            "type": "CalculatedMobileMetricUserActionFilter.OrientationEnum"
        },
        {
            "name": "resolution",
            "baseName": "resolution",
            "type": "CalculatedMobileMetricUserActionFilter.ResolutionEnum"
        }    ];

    static getAttributeTypeMap() {
        return CalculatedMobileMetricUserActionFilter.attributeTypeMap;
    }
}

export namespace CalculatedMobileMetricUserActionFilter {
    export enum ApdexEnum {
        Frustrated = <any> 'Frustrated',
        Satisfied = <any> 'Satisfied',
        Tolerating = <any> 'Tolerating',
        Unknown = <any> 'Unknown'
    }
    export enum ConnectionTypeEnum {
        LAN = <any> 'LAN',
        MOBILE = <any> 'MOBILE',
        OFFLINE = <any> 'OFFLINE',
        UNKNOWN = <any> 'UNKNOWN',
        WIFI = <any> 'WIFI'
    }
    export enum OrientationEnum {
        LANDSCAPE = <any> 'LANDSCAPE',
        PORTRAIT = <any> 'PORTRAIT',
        UNKNOWN = <any> 'UNKNOWN'
    }
    export enum ResolutionEnum {
        CGA = <any> 'CGA',
        DCI2K = <any> 'DCI2K',
        DCI4K = <any> 'DCI4K',
        DVGA = <any> 'DVGA',
        FHD = <any> 'FHD',
        FWVGA = <any> 'FWVGA',
        FWXGA = <any> 'FWXGA',
        GHDPlus = <any> 'GHDPlus',
        HD = <any> 'HD',
        HQVGA = <any> 'HQVGA',
        HQVGA2 = <any> 'HQVGA2',
        HSXGA = <any> 'HSXGA',
        HUXGA = <any> 'HUXGA',
        HVGA = <any> 'HVGA',
        HXGA = <any> 'HXGA',
        NTSC = <any> 'NTSC',
        PAL = <any> 'PAL',
        QHD = <any> 'QHD',
        QQVGA = <any> 'QQVGA',
        QSXGA = <any> 'QSXGA',
        QUXGA = <any> 'QUXGA',
        QVGA = <any> 'QVGA',
        QWXGA = <any> 'QWXGA',
        QXGA = <any> 'QXGA',
        SVGA = <any> 'SVGA',
        SXGA = <any> 'SXGA',
        SXGAMinus = <any> 'SXGAMinus',
        SXGAPlus = <any> 'SXGAPlus',
        UGA = <any> 'UGA',
        UHD16K = <any> 'UHD16K',
        UHD4K = <any> 'UHD4K',
        UHD8K = <any> 'UHD8K',
        UHDPlus = <any> 'UHDPlus',
        UNKNOWN = <any> 'UNKNOWN',
        UWQHD = <any> 'UWQHD',
        UXGA = <any> 'UXGA',
        VGA = <any> 'VGA',
        WHSXGA = <any> 'WHSXGA',
        WHUXGA = <any> 'WHUXGA',
        WHXGA = <any> 'WHXGA',
        WQSXGA = <any> 'WQSXGA',
        WQUXGA = <any> 'WQUXGA',
        WQVGA = <any> 'WQVGA',
        WQVGA2 = <any> 'WQVGA2',
        WQVGA3 = <any> 'WQVGA3',
        WQXGA = <any> 'WQXGA',
        WQXGA2 = <any> 'WQXGA2',
        WSVGA = <any> 'WSVGA',
        WSVGA2 = <any> 'WSVGA2',
        WSXGA = <any> 'WSXGA',
        WSXGAPlus = <any> 'WSXGAPlus',
        WUXGA = <any> 'WUXGA',
        WVGA = <any> 'WVGA',
        WVGA2 = <any> 'WVGA2',
        WXGA = <any> 'WXGA',
        WXGA2 = <any> 'WXGA2',
        WXGA3 = <any> 'WXGA3',
        WXGAPlus = <any> 'WXGAPlus',
        XGA = <any> 'XGA',
        XGAPLUS = <any> 'XGAPLUS',
        _1280x854 = <any> '_1280x854',
        NHD = <any> 'nHD',
        QHD = <any> 'qHD'
    }
}
