/**
 * Dynatrace Configuration API
 * Documentation of the Dynatrace Configuration API. Refer to the [help page](https://www.dynatrace.com/support/help/shortlink/config-api) to read about use-cases and examples.  Notes about compatibility: * Operations marked as early adopter or preview may be changed in non-compatible ways, although we try to avoid this. * We may add new enum constants without incrementing the API version; thus, clients need to handle unknown enum constants gracefully.
 *
 * The version of the OpenAPI document: 1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { RequestFile } from '../api';
import { CalculatedMetricDefinition } from './calculatedMetricDefinition';
import { Condition } from './condition';
import { ConfigurationMetadata } from './configurationMetadata';
import { DimensionDefinition } from './dimensionDefinition';

/**
* Descriptor of a calculated service metric.
*/
export class CalculatedServiceMetric {
    'metadata'?: ConfigurationMetadata;
    /**
    * The key of the calculated service metric.
    */
    'tsmMetricKey': string;
    /**
    * The displayed name of the metric.
    */
    'name': string;
    /**
    * The metric is enabled (`true`) or disabled (`false`).
    */
    'enabled': boolean;
    'metricDefinition': CalculatedMetricDefinition;
    /**
    * The unit of the metric.
    */
    'unit': CalculatedServiceMetric.UnitEnum;
    /**
    * The display name of the metric\'s unit.    Only applicable when the **unit** parameter is set to `UNSPECIFIED`.
    */
    'unitDisplayName'?: string;
    /**
    * Restricts the metric usage to the specified service.    This field is mutually exclusive with the **managementZones** field.
    */
    'entityId'?: string;
    /**
    * Restricts the metric usage to specified management zones.    This field is mutually exclusive with the **entityId** field.
    */
    'managementZones'?: Array<string>;
    /**
    * The set of conditions for the metric usage.    **All** the specified conditions must be fulfilled to use the metric.
    */
    'conditions'?: Array<Condition>;
    'dimensionDefinition'?: DimensionDefinition;

    static discriminator: string | undefined = undefined;

    static attributeTypeMap: Array<{name: string, baseName: string, type: string}> = [
        {
            "name": "metadata",
            "baseName": "metadata",
            "type": "ConfigurationMetadata"
        },
        {
            "name": "tsmMetricKey",
            "baseName": "tsmMetricKey",
            "type": "string"
        },
        {
            "name": "name",
            "baseName": "name",
            "type": "string"
        },
        {
            "name": "enabled",
            "baseName": "enabled",
            "type": "boolean"
        },
        {
            "name": "metricDefinition",
            "baseName": "metricDefinition",
            "type": "CalculatedMetricDefinition"
        },
        {
            "name": "unit",
            "baseName": "unit",
            "type": "CalculatedServiceMetric.UnitEnum"
        },
        {
            "name": "unitDisplayName",
            "baseName": "unitDisplayName",
            "type": "string"
        },
        {
            "name": "entityId",
            "baseName": "entityId",
            "type": "string"
        },
        {
            "name": "managementZones",
            "baseName": "managementZones",
            "type": "Array<string>"
        },
        {
            "name": "conditions",
            "baseName": "conditions",
            "type": "Array<Condition>"
        },
        {
            "name": "dimensionDefinition",
            "baseName": "dimensionDefinition",
            "type": "DimensionDefinition"
        }    ];

    static getAttributeTypeMap() {
        return CalculatedServiceMetric.attributeTypeMap;
    }
}

export namespace CalculatedServiceMetric {
    export enum UnitEnum {
        BIT = <any> 'BIT',
        BITPERHOUR = <any> 'BIT_PER_HOUR',
        BITPERMINUTE = <any> 'BIT_PER_MINUTE',
        BITPERSECOND = <any> 'BIT_PER_SECOND',
        BYTE = <any> 'BYTE',
        BYTEPERHOUR = <any> 'BYTE_PER_HOUR',
        BYTEPERMINUTE = <any> 'BYTE_PER_MINUTE',
        BYTEPERSECOND = <any> 'BYTE_PER_SECOND',
        CORES = <any> 'CORES',
        COUNT = <any> 'COUNT',
        DAY = <any> 'DAY',
        GIBIBYTE = <any> 'GIBI_BYTE',
        GIGA = <any> 'GIGA',
        GIGABYTE = <any> 'GIGA_BYTE',
        HOUR = <any> 'HOUR',
        KIBIBYTE = <any> 'KIBI_BYTE',
        KIBIBYTEPERHOUR = <any> 'KIBI_BYTE_PER_HOUR',
        KIBIBYTEPERMINUTE = <any> 'KIBI_BYTE_PER_MINUTE',
        KIBIBYTEPERSECOND = <any> 'KIBI_BYTE_PER_SECOND',
        KILO = <any> 'KILO',
        KILOBYTE = <any> 'KILO_BYTE',
        KILOBYTEPERHOUR = <any> 'KILO_BYTE_PER_HOUR',
        KILOBYTEPERMINUTE = <any> 'KILO_BYTE_PER_MINUTE',
        KILOBYTEPERSECOND = <any> 'KILO_BYTE_PER_SECOND',
        MEBIBYTE = <any> 'MEBI_BYTE',
        MEBIBYTEPERHOUR = <any> 'MEBI_BYTE_PER_HOUR',
        MEBIBYTEPERMINUTE = <any> 'MEBI_BYTE_PER_MINUTE',
        MEBIBYTEPERSECOND = <any> 'MEBI_BYTE_PER_SECOND',
        MEGA = <any> 'MEGA',
        MEGABYTE = <any> 'MEGA_BYTE',
        MEGABYTEPERHOUR = <any> 'MEGA_BYTE_PER_HOUR',
        MEGABYTEPERMINUTE = <any> 'MEGA_BYTE_PER_MINUTE',
        MEGABYTEPERSECOND = <any> 'MEGA_BYTE_PER_SECOND',
        MICROSECOND = <any> 'MICRO_SECOND',
        MILLICORES = <any> 'MILLI_CORES',
        MILLISECOND = <any> 'MILLI_SECOND',
        MILLISECONDPERMINUTE = <any> 'MILLI_SECOND_PER_MINUTE',
        MINUTE = <any> 'MINUTE',
        MONTH = <any> 'MONTH',
        NANOSECOND = <any> 'NANO_SECOND',
        NANOSECONDPERMINUTE = <any> 'NANO_SECOND_PER_MINUTE',
        NOTAPPLICABLE = <any> 'NOT_APPLICABLE',
        PERCENT = <any> 'PERCENT',
        PERHOUR = <any> 'PER_HOUR',
        PERMINUTE = <any> 'PER_MINUTE',
        PERSECOND = <any> 'PER_SECOND',
        PIXEL = <any> 'PIXEL',
        PROMILLE = <any> 'PROMILLE',
        RATIO = <any> 'RATIO',
        SECOND = <any> 'SECOND',
        STATE = <any> 'STATE',
        UNSPECIFIED = <any> 'UNSPECIFIED',
        WEEK = <any> 'WEEK',
        YEAR = <any> 'YEAR'
    }
}
