/**
 * Dynatrace Configuration API
 * Documentation of the Dynatrace Configuration API. Refer to the [help page](https://www.dynatrace.com/support/help/shortlink/config-api) to read about use-cases and examples.  Notes about compatibility: * Operations marked as early adopter or preview may be changed in non-compatible ways, although we try to avoid this. * We may add new enum constants without incrementing the API version; thus, clients need to handle unknown enum constants gracefully.
 *
 * The version of the OpenAPI document: 1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { RequestFile } from '../api';
import { CapturedMethod } from './capturedMethod';
import { ScopeConditions } from './scopeConditions';
import { ValueCondition } from './valueCondition';
import { ValueProcessing } from './valueProcessing';

export class DataSource {
    /**
    * The data source is enabled (`true`) or disabled (`false`).
    */
    'enabled': boolean;
    /**
    * The source of the attribute to capture. Works in conjunction with **parameterName** or **methods** and **technology**.
    */
    'source': DataSource.SourceEnum;
    'valueProcessing'?: ValueProcessing;
    /**
    * The technology of the method to capture if the **source** value is `METHOD_PARAM`. \\n\\n Not applicable in other cases.
    */
    'technology'?: DataSource.TechnologyEnum;
    /**
    * The technology of the session attribute to capture if the **source** value is `SESSION_ATTRIBUTE`. \\n\\n Not applicable in other cases.
    */
    'sessionAttributeTechnology'?: DataSource.SessionAttributeTechnologyEnum;
    /**
    * The method specification if the **source** value is `METHOD_PARAM`.    Not applicable in other cases.
    */
    'methods'?: Array<CapturedMethod>;
    /**
    * The name of the web request parameter to capture.   Required if the **source** is one of the following: `POST_PARAMETER`, `GET_PARAMETER`, `REQUEST_HEADER`, `RESPONSE_HEADER`, `CUSTOM_ATTRIBUTE`.   Not applicable in other cases.
    */
    'parameterName'?: string;
    'scope'?: ScopeConditions;
    /**
    * Specifies the location where the values are captured and stored.   Required if the **source** is one of the following: `GET_PARAMETER`, `URI`, `REQUEST_HEADER`, `RESPONSE_HEADER`.    Not applicable in other cases.    If the **source** value is `REQUEST_HEADER` or `RESPONSE_HEADER`, the `CAPTURE_AND_STORE_ON_BOTH` location is not allowed.
    */
    'capturingAndStorageLocation'?: DataSource.CapturingAndStorageLocationEnum;
    /**
    * The IBM integration bus node type for which the value is captured.   This or `iibMethodNodeCondition` is required if the **source** is: `IIB_NODE`.   Not applicable in other cases.
    */
    'iibNodeType'?: DataSource.IibNodeTypeEnum;
    'iibMethodNodeCondition'?: ValueCondition;
    'cicsSDKMethodNodeCondition'?: ValueCondition;
    'iibLabelMethodNodeCondition'?: ValueCondition;

    static discriminator: string | undefined = undefined;

    static attributeTypeMap: Array<{name: string, baseName: string, type: string}> = [
        {
            "name": "enabled",
            "baseName": "enabled",
            "type": "boolean"
        },
        {
            "name": "source",
            "baseName": "source",
            "type": "DataSource.SourceEnum"
        },
        {
            "name": "valueProcessing",
            "baseName": "valueProcessing",
            "type": "ValueProcessing"
        },
        {
            "name": "technology",
            "baseName": "technology",
            "type": "DataSource.TechnologyEnum"
        },
        {
            "name": "sessionAttributeTechnology",
            "baseName": "sessionAttributeTechnology",
            "type": "DataSource.SessionAttributeTechnologyEnum"
        },
        {
            "name": "methods",
            "baseName": "methods",
            "type": "Array<CapturedMethod>"
        },
        {
            "name": "parameterName",
            "baseName": "parameterName",
            "type": "string"
        },
        {
            "name": "scope",
            "baseName": "scope",
            "type": "ScopeConditions"
        },
        {
            "name": "capturingAndStorageLocation",
            "baseName": "capturingAndStorageLocation",
            "type": "DataSource.CapturingAndStorageLocationEnum"
        },
        {
            "name": "iibNodeType",
            "baseName": "iibNodeType",
            "type": "DataSource.IibNodeTypeEnum"
        },
        {
            "name": "iibMethodNodeCondition",
            "baseName": "iibMethodNodeCondition",
            "type": "ValueCondition"
        },
        {
            "name": "cicsSDKMethodNodeCondition",
            "baseName": "cicsSDKMethodNodeCondition",
            "type": "ValueCondition"
        },
        {
            "name": "iibLabelMethodNodeCondition",
            "baseName": "iibLabelMethodNodeCondition",
            "type": "ValueCondition"
        }    ];

    static getAttributeTypeMap() {
        return DataSource.attributeTypeMap;
    }
}

export namespace DataSource {
    export enum SourceEnum {
        CICSSDK = <any> 'CICS_SDK',
        CLIENTIP = <any> 'CLIENT_IP',
        CUSTOMATTRIBUTE = <any> 'CUSTOM_ATTRIBUTE',
        IIBLABEL = <any> 'IIB_LABEL',
        IIBNODE = <any> 'IIB_NODE',
        METHODPARAM = <any> 'METHOD_PARAM',
        POSTPARAMETER = <any> 'POST_PARAMETER',
        QUERYPARAMETER = <any> 'QUERY_PARAMETER',
        REQUESTHEADER = <any> 'REQUEST_HEADER',
        RESPONSEHEADER = <any> 'RESPONSE_HEADER',
        SESSIONATTRIBUTE = <any> 'SESSION_ATTRIBUTE',
        URI = <any> 'URI',
        URIPATH = <any> 'URI_PATH'
    }
    export enum TechnologyEnum {
        DOTNET = <any> 'DOTNET',
        JAVA = <any> 'JAVA',
        PHP = <any> 'PHP'
    }
    export enum SessionAttributeTechnologyEnum {
        ASPNET = <any> 'ASP_NET',
        ASPNETCORE = <any> 'ASP_NET_CORE',
        JAVA = <any> 'JAVA'
    }
    export enum CapturingAndStorageLocationEnum {
        ANDSTOREONBOTH = <any> 'CAPTURE_AND_STORE_ON_BOTH',
        ANDSTOREONCLIENT = <any> 'CAPTURE_AND_STORE_ON_CLIENT',
        ANDSTOREONSERVER = <any> 'CAPTURE_AND_STORE_ON_SERVER',
        ONCLIENTSTOREONSERVER = <any> 'CAPTURE_ON_CLIENT_STORE_ON_SERVER'
    }
    export enum IibNodeTypeEnum {
        AGGREGATECONTROLNODE = <any> 'AGGREGATE_CONTROL_NODE',
        AGGREGATEREPLYNODE = <any> 'AGGREGATE_REPLY_NODE',
        AGGREGATEREQUESTNODE = <any> 'AGGREGATE_REQUEST_NODE',
        CALLABLEFLOWREPLYNODE = <any> 'CALLABLE_FLOW_REPLY_NODE',
        COLLECTORNODE = <any> 'COLLECTOR_NODE',
        COMPUTENODE = <any> 'COMPUTE_NODE',
        DATABASENODE = <any> 'DATABASE_NODE',
        DECISIONSERVICENODE = <any> 'DECISION_SERVICE_NODE',
        DOTNETCOMPUTENODE = <any> 'DOT_NET_COMPUTE_NODE',
        FILEREADNODE = <any> 'FILE_READ_NODE',
        FILTERNODE = <any> 'FILTER_NODE',
        FLOWORDERNODE = <any> 'FLOW_ORDER_NODE',
        GROUPCOMPLETENODE = <any> 'GROUP_COMPLETE_NODE',
        GROUPGATHERNODE = <any> 'GROUP_GATHER_NODE',
        GROUPSCATTERNODE = <any> 'GROUP_SCATTER_NODE',
        HTTPHEADER = <any> 'HTTP_HEADER',
        JAVACOMPUTENODE = <any> 'JAVA_COMPUTE_NODE',
        JMSCLIENTRECEIVE = <any> 'JMS_CLIENT_RECEIVE',
        JMSCLIENTREPLYNODE = <any> 'JMS_CLIENT_REPLY_NODE',
        JMSHEADER = <any> 'JMS_HEADER',
        MQGETNODE = <any> 'MQ_GET_NODE',
        MQOUTPUTNODE = <any> 'MQ_OUTPUT_NODE',
        PASSTHRUNODE = <any> 'PASSTHRU_NODE',
        RESETCONTENTDESCRIPTORNODE = <any> 'RESET_CONTENT_DESCRIPTOR_NODE',
        RESEQUENCENODE = <any> 'RE_SEQUENCE_NODE',
        ROUTENODE = <any> 'ROUTE_NODE',
        SAPREPLYNODE = <any> 'SAP_REPLY_NODE',
        SCAREPLYNODE = <any> 'SCA_REPLY_NODE',
        SECURITYPEP = <any> 'SECURITY_PEP',
        SEQUENCENODE = <any> 'SEQUENCE_NODE',
        SOAPEXTRACTNODE = <any> 'SOAP_EXTRACT_NODE',
        SOAPREPLYNODE = <any> 'SOAP_REPLY_NODE',
        SOAPWRAPPERNODE = <any> 'SOAP_WRAPPER_NODE',
        SRRETRIEVEENTITYNODE = <any> 'SR_RETRIEVE_ENTITY_NODE',
        SRRETRIEVEITSERVICENODE = <any> 'SR_RETRIEVE_IT_SERVICE_NODE',
        THROWNODE = <any> 'THROW_NODE',
        TRACENODE = <any> 'TRACE_NODE',
        TRYCATCHNODE = <any> 'TRY_CATCH_NODE',
        VALIDATENODE = <any> 'VALIDATE_NODE',
        WSREPLYNODE = <any> 'WS_REPLY_NODE',
        XSLMQSINODE = <any> 'XSL_MQSI_NODE'
    }
}
