/**
 * Dynatrace Configuration API
 * Documentation of the Dynatrace Configuration API. Refer to the [help page](https://www.dynatrace.com/support/help/shortlink/config-api) to read about use-cases and examples.  Notes about compatibility: * Operations marked as early adopter or preview may be changed in non-compatible ways, although we try to avoid this. * We may add new enum constants without incrementing the API version; thus, clients need to handle unknown enum constants gracefully.
 *
 * The version of the OpenAPI document: 1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { RequestFile } from '../api';
import { ConfigurationMetadata } from './configurationMetadata';
import { KubernetesEventPattern } from './kubernetesEventPattern';

/**
* Configuration for specific Kubernetes credentials.
*/
export class KubernetesCredentials {
    'metadata'?: ConfigurationMetadata;
    /**
    * The ID of the given credentials configuration.
    */
    'id'?: string;
    /**
    * The monitoring is enabled (`true`) or disabled (`false`) for given credentials configuration.   If not set on creation, the `true` value is used.   If the field is omitted during an update, the old value remains unaffected.
    */
    'active'?: boolean;
    /**
    * The status of the configured endpoint.  ASSIGNED: The credentials are assigned to an ActiveGate which is responsible for processing. UNASSIGNED: The credentials are not yet assigned to an ActiveGate so there is currently no processing. DISABLED: The credentials have been disabled by the user. FASTCHECK_AUTH_ERROR: The credentials are invalid. FASTCHECK_TLS_ERROR: The endpoint TLS certificate is invalid. FASTCHECK_NO_RESPONSE: The endpoint did not return a result until the timeout was reached. FASTCHECK_INVALID_ENDPOINT: The endpoint URL was invalid. FASTCHECK_AUTH_LOCKED: The credentials seem to be locked. UNKNOWN: An unknown error occured. 
    */
    'endpointStatus'?: KubernetesCredentials.EndpointStatusEnum;
    /**
    * The detailed status info of the configured endpoint.
    */
    'endpointStatusInfo'?: string;
    /**
    * The name of the Kubernetes credentials configuration.   Allowed characters are letters, numbers, whitespaces, and the following characters: `.+-_`. Leading or trailing whitespace is not allowed.
    */
    'label': string;
    /**
    * The URL of the Kubernetes API server.   It must be unique within a Dynatrace environment.   The URL must valid according to RFC 2396. Leading or trailing whitespaces are not allowed.
    */
    'endpointUrl'?: string;
    /**
    * The service account bearer token for the Kubernetes API server.   Submit your token on creation or update of the configuration. For security reasons, GET requests return this field as `null`.   If the field is omitted during an update, the old value remains unaffected.
    */
    'authToken'?: string;
    /**
    * The monitoring of events is enabled (`true`) or disabled (`false`) for the Kubernetes cluster. Event monitoring depends on the active state of this configuration to be true.   If not set on creation, the `false` value is used.   If the field is omitted during an update, the old value remains unaffected.
    */
    'eventsIntegrationEnabled'?: boolean;
    /**
    * Workload and cloud application processing is enabled (`true`) or disabled (`false`) for the Kubernetes cluster. If the field is omitted during an update, the old value remains unaffected.
    */
    'workloadIntegrationEnabled'?: boolean;
    /**
    * Kubernetes event filters based on field-selectors. If set to `null` on creation, no events field selectors are subscribed. If set to `null` on update, no change of stored events field selectors is applied. Set an empty list to clear all events field selectors.
    */
    'eventsFieldSelectors'?: Array<KubernetesEventPattern>;
    /**
    * The check of SSL certificates is enabled (`true`) or disabled (`false`) for the Kubernetes cluster.   If not set on creation, the `true` value is used.   If the field is omitted during an update, the old value remains unaffected.
    */
    'certificateCheckEnabled'?: boolean;

    static discriminator: string | undefined = undefined;

    static attributeTypeMap: Array<{name: string, baseName: string, type: string}> = [
        {
            "name": "metadata",
            "baseName": "metadata",
            "type": "ConfigurationMetadata"
        },
        {
            "name": "id",
            "baseName": "id",
            "type": "string"
        },
        {
            "name": "active",
            "baseName": "active",
            "type": "boolean"
        },
        {
            "name": "endpointStatus",
            "baseName": "endpointStatus",
            "type": "KubernetesCredentials.EndpointStatusEnum"
        },
        {
            "name": "endpointStatusInfo",
            "baseName": "endpointStatusInfo",
            "type": "string"
        },
        {
            "name": "label",
            "baseName": "label",
            "type": "string"
        },
        {
            "name": "endpointUrl",
            "baseName": "endpointUrl",
            "type": "string"
        },
        {
            "name": "authToken",
            "baseName": "authToken",
            "type": "string"
        },
        {
            "name": "eventsIntegrationEnabled",
            "baseName": "eventsIntegrationEnabled",
            "type": "boolean"
        },
        {
            "name": "workloadIntegrationEnabled",
            "baseName": "workloadIntegrationEnabled",
            "type": "boolean"
        },
        {
            "name": "eventsFieldSelectors",
            "baseName": "eventsFieldSelectors",
            "type": "Array<KubernetesEventPattern>"
        },
        {
            "name": "certificateCheckEnabled",
            "baseName": "certificateCheckEnabled",
            "type": "boolean"
        }    ];

    static getAttributeTypeMap() {
        return KubernetesCredentials.attributeTypeMap;
    }
}

export namespace KubernetesCredentials {
    export enum EndpointStatusEnum {
        ASSIGNED = <any> 'ASSIGNED',
        DISABLED = <any> 'DISABLED',
        FASTCHECKAUTHERROR = <any> 'FASTCHECK_AUTH_ERROR',
        FASTCHECKAUTHLOCKED = <any> 'FASTCHECK_AUTH_LOCKED',
        FASTCHECKINVALIDENDPOINT = <any> 'FASTCHECK_INVALID_ENDPOINT',
        FASTCHECKNORESPONSE = <any> 'FASTCHECK_NO_RESPONSE',
        FASTCHECKTLSERROR = <any> 'FASTCHECK_TLS_ERROR',
        UNASSIGNED = <any> 'UNASSIGNED',
        UNKNOWN = <any> 'UNKNOWN'
    }
}
