/**
 * Dynatrace Configuration API
 * Documentation of the Dynatrace Configuration API. Refer to the [help page](https://www.dynatrace.com/support/help/shortlink/config-api) to read about use-cases and examples.  Notes about compatibility: * Operations marked as early adopter or preview may be changed in non-compatible ways, although we try to avoid this. * We may add new enum constants without incrementing the API version; thus, clients need to handle unknown enum constants gracefully.
 *
 * The version of the OpenAPI document: 1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { RequestFile } from '../api';
import { ColumnDefinition } from './columnDefinition';
import { LogSourceFilter } from './logSourceFilter';

/**
* Custom log metric definition.
*/
export class LogMetricConfig {
    /**
    * The unique key of the metric.   The key must have the `calc:log.` prefix.
    */
    'metricKey': string;
    /**
    * The metric is enabled (`true`) or disabled (`false`).
    */
    'active'?: boolean;
    /**
    * The name of the metric, displayed in the UI.
    */
    'displayName': string;
    /**
    * The unit of the metric.
    */
    'unit': LogMetricConfig.UnitEnum;
    /**
    * The display name of the unit.    Only applicable if the **unit** is set to `UNSPECIFIED`.
    */
    'unitDisplayName'?: string;
    /**
    * The pattern to look for in logs.    Use the [Dynatrace search query language](https://www.dynatrace.com/support/help/shortlink/log-viewer#search-for-text-patterns-in-log-files) to specify it. Quotes must be escaped.    To return all results, leave the field blank.
    */
    'searchString': string;
    /**
    * The type of the metric data points calculation. For now the only allowed value is `OCCURRENCES`.
    */
    'metricValueType': LogMetricConfig.MetricValueTypeEnum;
    'columnDefiningValue'?: ColumnDefinition;
    /**
    * A list of filters to define the logs to look into.    If several filters are specified, the OR logic applies.
    */
    'logSourceFilters': Array<LogSourceFilter>;

    static discriminator: string | undefined = undefined;

    static attributeTypeMap: Array<{name: string, baseName: string, type: string}> = [
        {
            "name": "metricKey",
            "baseName": "metricKey",
            "type": "string"
        },
        {
            "name": "active",
            "baseName": "active",
            "type": "boolean"
        },
        {
            "name": "displayName",
            "baseName": "displayName",
            "type": "string"
        },
        {
            "name": "unit",
            "baseName": "unit",
            "type": "LogMetricConfig.UnitEnum"
        },
        {
            "name": "unitDisplayName",
            "baseName": "unitDisplayName",
            "type": "string"
        },
        {
            "name": "searchString",
            "baseName": "searchString",
            "type": "string"
        },
        {
            "name": "metricValueType",
            "baseName": "metricValueType",
            "type": "LogMetricConfig.MetricValueTypeEnum"
        },
        {
            "name": "columnDefiningValue",
            "baseName": "columnDefiningValue",
            "type": "ColumnDefinition"
        },
        {
            "name": "logSourceFilters",
            "baseName": "logSourceFilters",
            "type": "Array<LogSourceFilter>"
        }    ];

    static getAttributeTypeMap() {
        return LogMetricConfig.attributeTypeMap;
    }
}

export namespace LogMetricConfig {
    export enum UnitEnum {
        BIT = <any> 'BIT',
        BITPERHOUR = <any> 'BIT_PER_HOUR',
        BITPERMINUTE = <any> 'BIT_PER_MINUTE',
        BITPERSECOND = <any> 'BIT_PER_SECOND',
        BYTE = <any> 'BYTE',
        BYTEPERHOUR = <any> 'BYTE_PER_HOUR',
        BYTEPERMINUTE = <any> 'BYTE_PER_MINUTE',
        BYTEPERSECOND = <any> 'BYTE_PER_SECOND',
        CORES = <any> 'CORES',
        COUNT = <any> 'COUNT',
        DAY = <any> 'DAY',
        GIBIBYTE = <any> 'GIBI_BYTE',
        GIGA = <any> 'GIGA',
        GIGABYTE = <any> 'GIGA_BYTE',
        HOUR = <any> 'HOUR',
        KIBIBYTE = <any> 'KIBI_BYTE',
        KIBIBYTEPERHOUR = <any> 'KIBI_BYTE_PER_HOUR',
        KIBIBYTEPERMINUTE = <any> 'KIBI_BYTE_PER_MINUTE',
        KIBIBYTEPERSECOND = <any> 'KIBI_BYTE_PER_SECOND',
        KILO = <any> 'KILO',
        KILOBYTE = <any> 'KILO_BYTE',
        KILOBYTEPERHOUR = <any> 'KILO_BYTE_PER_HOUR',
        KILOBYTEPERMINUTE = <any> 'KILO_BYTE_PER_MINUTE',
        KILOBYTEPERSECOND = <any> 'KILO_BYTE_PER_SECOND',
        MEBIBYTE = <any> 'MEBI_BYTE',
        MEBIBYTEPERHOUR = <any> 'MEBI_BYTE_PER_HOUR',
        MEBIBYTEPERMINUTE = <any> 'MEBI_BYTE_PER_MINUTE',
        MEBIBYTEPERSECOND = <any> 'MEBI_BYTE_PER_SECOND',
        MEGA = <any> 'MEGA',
        MEGABYTE = <any> 'MEGA_BYTE',
        MEGABYTEPERHOUR = <any> 'MEGA_BYTE_PER_HOUR',
        MEGABYTEPERMINUTE = <any> 'MEGA_BYTE_PER_MINUTE',
        MEGABYTEPERSECOND = <any> 'MEGA_BYTE_PER_SECOND',
        MICROSECOND = <any> 'MICRO_SECOND',
        MILLICORES = <any> 'MILLI_CORES',
        MILLISECOND = <any> 'MILLI_SECOND',
        MILLISECONDPERMINUTE = <any> 'MILLI_SECOND_PER_MINUTE',
        MINUTE = <any> 'MINUTE',
        MONTH = <any> 'MONTH',
        NANOSECOND = <any> 'NANO_SECOND',
        NANOSECONDPERMINUTE = <any> 'NANO_SECOND_PER_MINUTE',
        NOTAPPLICABLE = <any> 'NOT_APPLICABLE',
        PERCENT = <any> 'PERCENT',
        PERHOUR = <any> 'PER_HOUR',
        PERMINUTE = <any> 'PER_MINUTE',
        PERSECOND = <any> 'PER_SECOND',
        PIXEL = <any> 'PIXEL',
        PROMILLE = <any> 'PROMILLE',
        RATIO = <any> 'RATIO',
        SECOND = <any> 'SECOND',
        STATE = <any> 'STATE',
        UNSPECIFIED = <any> 'UNSPECIFIED',
        WEEK = <any> 'WEEK',
        YEAR = <any> 'YEAR'
    }
    export enum MetricValueTypeEnum {
        FPCOLUMNAVG = <any> 'FP_COLUMN_AVG',
        FPCOLUMNCOUNT = <any> 'FP_COLUMN_COUNT',
        FPCOLUMNMAX = <any> 'FP_COLUMN_MAX',
        FPCOLUMNMIN = <any> 'FP_COLUMN_MIN',
        FPCOLUMNSUM = <any> 'FP_COLUMN_SUM',
        FPCOLUMNTOPXAVG = <any> 'FP_COLUMN_TOP_X_AVG',
        FPCOLUMNTOPXCOUNT = <any> 'FP_COLUMN_TOP_X_COUNT',
        FPCOLUMNTOPXMAX = <any> 'FP_COLUMN_TOP_X_MAX',
        FPCOLUMNTOPXMIN = <any> 'FP_COLUMN_TOP_X_MIN',
        FPCOLUMNTOPXSUM = <any> 'FP_COLUMN_TOP_X_SUM',
        INTCOLUMNAVG = <any> 'INT_COLUMN_AVG',
        INTCOLUMNCOUNT = <any> 'INT_COLUMN_COUNT',
        INTCOLUMNMAX = <any> 'INT_COLUMN_MAX',
        INTCOLUMNMIN = <any> 'INT_COLUMN_MIN',
        INTCOLUMNSUM = <any> 'INT_COLUMN_SUM',
        INTCOLUMNTOPXAVG = <any> 'INT_COLUMN_TOP_X_AVG',
        INTCOLUMNTOPXCOUNT = <any> 'INT_COLUMN_TOP_X_COUNT',
        INTCOLUMNTOPXMAX = <any> 'INT_COLUMN_TOP_X_MAX',
        INTCOLUMNTOPXMIN = <any> 'INT_COLUMN_TOP_X_MIN',
        INTCOLUMNTOPXSUM = <any> 'INT_COLUMN_TOP_X_SUM',
        OCCURRENCES = <any> 'OCCURRENCES'
    }
}
