/**
 * Dynatrace Configuration API
 * Documentation of the Dynatrace Configuration API. Refer to the [help page](https://www.dynatrace.com/support/help/shortlink/config-api) to read about use-cases and examples.  Notes about compatibility: * Operations marked as early adopter or preview may be changed in non-compatible ways, although we try to avoid this. * We may add new enum constants without incrementing the API version; thus, clients need to handle unknown enum constants gracefully.
 *
 * The version of the OpenAPI document: 1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { RequestFile } from '../api';
import { ConfigurationMetadata } from './configurationMetadata';
import { MetricEventAlertingScope } from './metricEventAlertingScope';
import { MetricEventDimensions } from './metricEventDimensions';
import { MetricEventMonitoringStrategy } from './metricEventMonitoringStrategy';

/**
* The configuration of the metric event.
*/
export class MetricEvent {
    'metadata'?: ConfigurationMetadata;
    /**
    * The ID of the metric event.
    */
    'id'?: string;
    /**
    * The ID of the metric evaluated by the metric event.
    */
    'metricId': string;
    /**
    * The name of the metric event displayed in the UI.
    */
    'name': string;
    /**
    * The description of the metric event.
    */
    'description': string;
    /**
    * How the metric data points are aggregated for the evaluation.    The timeseries must support this aggregation.
    */
    'aggregationType'?: MetricEvent.AggregationTypeEnum;
    /**
    * The type of the event to trigger on the threshold violation.   The `CUSTOM_ALERT` type is not correlated with other alerts. The `INFO` type does not open a problem.
    */
    'severity'?: MetricEvent.SeverityEnum;
    /**
    * The metric event is enabled (`true`) or disabled (`false`).
    */
    'enabled': boolean;
    /**
    * The reason of automatic disabling.   The `NONE` means config was not disabled automatically.
    */
    'disabledReason'?: MetricEvent.DisabledReasonEnum;
    /**
    * Defines the scope of the metric event. Only one filter is allowed per filter type, except for tags, where up to 3 are allowed. The filters are combined by conjunction.
    */
    'alertingScope'?: Array<MetricEventAlertingScope>;
    /**
    * Defines the dimensions of the metric to alert on. The filters are combined by conjunction.
    */
    'metricDimensions'?: Array<MetricEventDimensions>;
    'monitoringStrategy'?: MetricEventMonitoringStrategy;

    static discriminator: string | undefined = undefined;

    static attributeTypeMap: Array<{name: string, baseName: string, type: string}> = [
        {
            "name": "metadata",
            "baseName": "metadata",
            "type": "ConfigurationMetadata"
        },
        {
            "name": "id",
            "baseName": "id",
            "type": "string"
        },
        {
            "name": "metricId",
            "baseName": "metricId",
            "type": "string"
        },
        {
            "name": "name",
            "baseName": "name",
            "type": "string"
        },
        {
            "name": "description",
            "baseName": "description",
            "type": "string"
        },
        {
            "name": "aggregationType",
            "baseName": "aggregationType",
            "type": "MetricEvent.AggregationTypeEnum"
        },
        {
            "name": "severity",
            "baseName": "severity",
            "type": "MetricEvent.SeverityEnum"
        },
        {
            "name": "enabled",
            "baseName": "enabled",
            "type": "boolean"
        },
        {
            "name": "disabledReason",
            "baseName": "disabledReason",
            "type": "MetricEvent.DisabledReasonEnum"
        },
        {
            "name": "alertingScope",
            "baseName": "alertingScope",
            "type": "Array<MetricEventAlertingScope>"
        },
        {
            "name": "metricDimensions",
            "baseName": "metricDimensions",
            "type": "Array<MetricEventDimensions>"
        },
        {
            "name": "monitoringStrategy",
            "baseName": "monitoringStrategy",
            "type": "MetricEventMonitoringStrategy"
        }    ];

    static getAttributeTypeMap() {
        return MetricEvent.attributeTypeMap;
    }
}

export namespace MetricEvent {
    export enum AggregationTypeEnum {
        AVG = <any> 'AVG',
        COUNT = <any> 'COUNT',
        MAX = <any> 'MAX',
        MEDIAN = <any> 'MEDIAN',
        MIN = <any> 'MIN',
        OFINTEREST = <any> 'OF_INTEREST',
        OFINTERESTRATIO = <any> 'OF_INTEREST_RATIO',
        OTHER = <any> 'OTHER',
        OTHERRATIO = <any> 'OTHER_RATIO',
        P90 = <any> 'P90',
        SUM = <any> 'SUM',
        VALUE = <any> 'VALUE'
    }
    export enum SeverityEnum {
        AVAILABILITY = <any> 'AVAILABILITY',
        CUSTOMALERT = <any> 'CUSTOM_ALERT',
        ERROR = <any> 'ERROR',
        INFO = <any> 'INFO',
        PERFORMANCE = <any> 'PERFORMANCE',
        RESOURCECONTENTION = <any> 'RESOURCE_CONTENTION'
    }
    export enum DisabledReasonEnum {
        NONE = <any> 'NONE',
        TOOMANYDIMS = <any> 'TOO_MANY_DIMS'
    }
}
