/**
 * Dynatrace Configuration API
 * Documentation of the Dynatrace Configuration API. Refer to the [help page](https://www.dynatrace.com/support/help/shortlink/config-api) to read about use-cases and examples.  Notes about compatibility: * Operations marked as early adopter or preview may be changed in non-compatible ways, although we try to avoid this. * We may add new enum constants without incrementing the API version; thus, clients need to handle unknown enum constants gracefully.
 *
 * The version of the OpenAPI document: 1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { RequestFile } from '../api';
import { Apdex } from './apdex';
import { ConfigurationMetadata } from './configurationMetadata';
import { ConversionGoal } from './conversionGoal';
import { MetaDataCapturing } from './metaDataCapturing';
import { MonitoringSettings } from './monitoringSettings';
import { SessionReplaySetting } from './sessionReplaySetting';
import { UserActionAndSessionProperties } from './userActionAndSessionProperties';
import { UserActionNamingSettings } from './userActionNamingSettings';
import { UserTag } from './userTag';
import { WaterfallSettings } from './waterfallSettings';

/**
* Configuration of a web application.
*/
export class WebApplicationConfig {
    'metadata'?: ConfigurationMetadata;
    /**
    * Dynatrace entity ID of the web application.
    */
    'identifier'?: string;
    /**
    * The name of the web application, displayed in the UI.
    */
    'name': string;
    /**
    * The type of the web application.
    */
    'type'?: WebApplicationConfig.TypeEnum;
    /**
    * Real user monitoring enabled/disabled.
    */
    'realUserMonitoringEnabled': boolean;
    /**
    * Analize *X*% of user sessions.
    */
    'costControlUserSessionPercentage': number;
    /**
    * The key performance metric of load actions.
    */
    'loadActionKeyPerformanceMetric': WebApplicationConfig.LoadActionKeyPerformanceMetricEnum;
    'sessionReplayConfig'?: SessionReplaySetting;
    /**
    * The key performance metric of XHR actions.
    */
    'xhrActionKeyPerformanceMetric': WebApplicationConfig.XhrActionKeyPerformanceMetricEnum;
    'loadActionApdexSettings': Apdex;
    'xhrActionApdexSettings': Apdex;
    'customActionApdexSettings': Apdex;
    'waterfallSettings': WaterfallSettings;
    'monitoringSettings': MonitoringSettings;
    /**
    * User tags settings.
    */
    'userTags'?: Array<UserTag>;
    /**
    * User action and session properties settings. Empty List means no change
    */
    'userActionAndSessionProperties'?: Array<UserActionAndSessionProperties>;
    'userActionNamingSettings'?: UserActionNamingSettings;
    /**
    * Java script agent meta data capture settings.
    */
    'metaDataCaptureSettings'?: Array<MetaDataCapturing>;
    /**
    * A list of conversion goals of the application.
    */
    'conversionGoals'?: Array<ConversionGoal>;
    /**
    * Url injection pattern for manual web application.
    */
    'urlInjectionPattern'?: string;

    static discriminator: string | undefined = undefined;

    static attributeTypeMap: Array<{name: string, baseName: string, type: string}> = [
        {
            "name": "metadata",
            "baseName": "metadata",
            "type": "ConfigurationMetadata"
        },
        {
            "name": "identifier",
            "baseName": "identifier",
            "type": "string"
        },
        {
            "name": "name",
            "baseName": "name",
            "type": "string"
        },
        {
            "name": "type",
            "baseName": "type",
            "type": "WebApplicationConfig.TypeEnum"
        },
        {
            "name": "realUserMonitoringEnabled",
            "baseName": "realUserMonitoringEnabled",
            "type": "boolean"
        },
        {
            "name": "costControlUserSessionPercentage",
            "baseName": "costControlUserSessionPercentage",
            "type": "number"
        },
        {
            "name": "loadActionKeyPerformanceMetric",
            "baseName": "loadActionKeyPerformanceMetric",
            "type": "WebApplicationConfig.LoadActionKeyPerformanceMetricEnum"
        },
        {
            "name": "sessionReplayConfig",
            "baseName": "sessionReplayConfig",
            "type": "SessionReplaySetting"
        },
        {
            "name": "xhrActionKeyPerformanceMetric",
            "baseName": "xhrActionKeyPerformanceMetric",
            "type": "WebApplicationConfig.XhrActionKeyPerformanceMetricEnum"
        },
        {
            "name": "loadActionApdexSettings",
            "baseName": "loadActionApdexSettings",
            "type": "Apdex"
        },
        {
            "name": "xhrActionApdexSettings",
            "baseName": "xhrActionApdexSettings",
            "type": "Apdex"
        },
        {
            "name": "customActionApdexSettings",
            "baseName": "customActionApdexSettings",
            "type": "Apdex"
        },
        {
            "name": "waterfallSettings",
            "baseName": "waterfallSettings",
            "type": "WaterfallSettings"
        },
        {
            "name": "monitoringSettings",
            "baseName": "monitoringSettings",
            "type": "MonitoringSettings"
        },
        {
            "name": "userTags",
            "baseName": "userTags",
            "type": "Array<UserTag>"
        },
        {
            "name": "userActionAndSessionProperties",
            "baseName": "userActionAndSessionProperties",
            "type": "Array<UserActionAndSessionProperties>"
        },
        {
            "name": "userActionNamingSettings",
            "baseName": "userActionNamingSettings",
            "type": "UserActionNamingSettings"
        },
        {
            "name": "metaDataCaptureSettings",
            "baseName": "metaDataCaptureSettings",
            "type": "Array<MetaDataCapturing>"
        },
        {
            "name": "conversionGoals",
            "baseName": "conversionGoals",
            "type": "Array<ConversionGoal>"
        },
        {
            "name": "urlInjectionPattern",
            "baseName": "urlInjectionPattern",
            "type": "string"
        }    ];

    static getAttributeTypeMap() {
        return WebApplicationConfig.attributeTypeMap;
    }
}

export namespace WebApplicationConfig {
    export enum TypeEnum {
        AUTOINJECTED = <any> 'AUTO_INJECTED',
        BROWSEREXTENSIONINJECTED = <any> 'BROWSER_EXTENSION_INJECTED',
        MANUALLYINJECTED = <any> 'MANUALLY_INJECTED'
    }
    export enum LoadActionKeyPerformanceMetricEnum {
        ACTIONDURATION = <any> 'ACTION_DURATION',
        DOMINTERACTIVE = <any> 'DOM_INTERACTIVE',
        LOADEVENTEND = <any> 'LOAD_EVENT_END',
        LOADEVENTSTART = <any> 'LOAD_EVENT_START',
        RESPONSEEND = <any> 'RESPONSE_END',
        RESPONSESTART = <any> 'RESPONSE_START',
        SPEEDINDEX = <any> 'SPEED_INDEX',
        VISUALLYCOMPLETE = <any> 'VISUALLY_COMPLETE'
    }
    export enum XhrActionKeyPerformanceMetricEnum {
        ACTIONDURATION = <any> 'ACTION_DURATION',
        RESPONSEEND = <any> 'RESPONSE_END',
        RESPONSESTART = <any> 'RESPONSE_START',
        VISUALLYCOMPLETE = <any> 'VISUALLY_COMPLETE'
    }
}
